@@ -397,7 +397,7 @@ class StickProtocol():
         for id in users_id:
             senderKey = keys[id]
             preKey = PreKey.objects.get(keyId=senderKey['preKeyId'], user__id=id)
-            identityKey = Identity.objects.get(keyId=senderKey['identityKeyId'], user__id=id)
+            identityKey = IdentityKey.objects.get(keyId=senderKey['identityKeyId'], user__id=id)
             if id != user.id:  # Other user? Create a DSK
                 forUser = self.User.objects.get(id=senderKey['forUser'])
                 DecryptingSenderKey.objects.create(key=senderKey['key'],
@@ -411,7 +411,7 @@ class StickProtocol():
                                                    user=user, chainKey=senderKey['chainKey'],
                                                    public=senderKey['public'],
                                                    cipher=senderKey['cipher'])
-        if "group_id" in data: # TODO: REMOVE FROM HERE MAYBE?
+        if "group_id" in data:  # TODO: REMOVE FROM HERE MAYBE?
             user.just_added_groups.remove(data["group_id"])
 
     def process_standard_sender_keys(self, data, user):
@@ -442,7 +442,7 @@ class StickProtocol():
         old_ik = IdentityKey.objects.get(user=user, active=True)
         old_ik.active = False
         old_ik.save()
-        IdentityKey.objects.create(user=user, public=data['public'], signature=data["signature"],
+        IdentityKey.objects.create(user=user, public=data['public'],
                                    keyId=data['id'], cipher=data['cipher'], salt=data['salt'],
                                    timestamp=data['timestamp'], localId=data['localId'], active=True)
 
@@ -487,7 +487,8 @@ class StickProtocol():
             for senderKey in senderKeysList:
                 stickId = senderKey.partyId + senderKey.chainId
                 key = {'id': senderKey.keyId, 'chainKey': senderKey.chainKey, 'public': senderKey.public,
-                       'cipher': senderKey.cipher, 'stickId': stickId, 'step': senderKey.step, 'identityKeyId': senderKey.identityKey.id}
+                       'cipher': senderKey.cipher, 'stickId': stickId, 'step': senderKey.step,
+                       'identityKeyId': senderKey.identityKey.id}
                 senderKeys.append(key)
             bundle['senderKeys'] = senderKeys
             user.oneTimeId = uuid.uuid4()
